<div dir="rtl">

# پکیج عملیات حساب مجازی پلتفرم پاد

این پکیج شامل سرویس های زیر است
* تعریف قانون برداشت مستقیم از حساب مشتری
* افزایش موجودی مستقیم
* انتقال پول
* و ...

# نصب

برای نصب از طریق `pip` کافیه تا دستور زیر را اجرا کنید
```
pip install pod-virtual-account
```


# نمونه کد

نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>